<?php
/*--------------------------------------------------------------*\
	Description: Simple message board class.
	Author: Brian Lozier (brian@massassi.net)
\*--------------------------------------------------------------*/
class bBoard {

	var $db,
		$table;

	/*--------------------------------------------------------------*\
		Method: bBoard()
		Sets database/table defaults.
	\*--------------------------------------------------------------*/
	function bBoard(&$db, &$table) {
		$this->db = $db;
		$this->table = $table;
	}

	/*--------------------------------------------------------------*\
		Method: add_thread()
		Adds a new thread.
	\*--------------------------------------------------------------*/
	function add_thread($m_user, $m_text, $m_email, $m_subject) {
		// Validate the input
		if(!$m_user) $m_user = 'Anonymous';
		if(!$m_subject) $m_subject = '[No Subject]';
		$m_user = htmlspecialchars($m_user);
		$m_text = nl2br(htmlspecialchars($m_text));
		$m_email = htmlspecialchars($m_email);
		$m_subject = htmlspecialchars($m_subject);

		// Add to the database
		$query = sprintf(
			"INSERT INTO %s VALUES (NULL, NULL, '%s', '%s', '%s', '%s', 1, NULL)",
			$this->table, $m_user, $m_email, $m_subject, $m_text);
		$result = $this->db->query($query);
		return $result;
	}

	/*--------------------------------------------------------------*\
		Method: add_message()
		Adds a message to a current thread.
	\*--------------------------------------------------------------*/
	function add_message($m_user, $m_text, $m_parent, $m_email, $m_subject = NULL) {
		// Validate the input
		if(!$m_user) $m_user = 'Anonymous';
		if(!settype($m_parent, 'integer')) return FALSE;
		$m_user = htmlspecialchars($m_user);
		$m_text = nl2br(htmlspecialchars($m_text));
		$m_email = htmlspecialchars($m_email);
		$m_subject = htmlspecialchars($m_subject);

		// Add to the database
		$query = sprintf(
			"INSERT INTO %s VALUES (NULL, %d, '%s', '%s', '%s', '%s', 0, NULL)",
			$this->table, $m_parent, $m_user, $m_email, $m_subject, $m_text);
		$result = $this->db->query($query);
		if($result) {
			$query = sprintf("UPDATE %s SET m_posts = m_posts + 1 WHERE m_id = %d", $this->table, $m_parent);
			$result2 = $this->db->query($query);
		}
		return $result;
	}

	/*--------------------------------------------------------------*\
		Method: get_thread()
		Retrieves all messages under a certain thread.
	\*--------------------------------------------------------------*/
	function get_thread($m_id) {
		$query = sprintf("SELECT *, DATE_FORMAT(m_time, '%%m/%%d/%%Y') as m_date FROM %s WHERE m_id = %d OR m_parent = %d", $this->table, $m_id, $m_id);
		$result = $this->db->query($query);
		if(!$result) {
			return FALSE;
		}
		else {
			return $this->get_array($result);
		}
	}

	/*--------------------------------------------------------------*\
		Method: get_list()
		Retrieves all top-level posts.
	\*--------------------------------------------------------------*/
	function get_list() {
		$query = sprintf(
			"SELECT m_id, m_user, m_email, m_subject, m_posts, DATE_FORMAT(m_time, '%%m/%%d/%%Y') as m_date FROM %s WHERE m_parent IS NULL ORDER BY m_time DESC",
			$this->table, $this->table);
		$result = $this->db->query($query);
		if(!$result) {
			return FALSE;
		}
		else {
			return $this->get_array($result);
		}
	}

	/*--------------------------------------------------------------*\
		Method: get_array()
		Builds an array from a result set.
	\*--------------------------------------------------------------*/
	function get_array($result) {
			$array = array();
			while($row = $this->db->fetch_array($result)) {
				$array[] = $row;
			}
			return $array;
	}
}
?>
